
from kotonebot.kaa.common import sprite_path
from kotonebot.backend.core import Image, HintBox, HintPoint



class Common:
    
    ButtonClose = Image(path=sprite_path(r"b241eff8-039e-4734-bea2-e10da89426d8.png"), name="button_close.png")

    ButtonCompletion = Image(path=sprite_path(r"f53ff71d-54b5-44d2-9e48-ad2dee918fd1.png"), name="button_completion.png")

    ButtonConfirm = Image(path=sprite_path(r"fc64316e-8394-4019-a16f-d6e7bb83d9bf.png"), name="button_confirm.png")

    ButtonConfirmNoIcon = Image(path=sprite_path(r"c84958c3-37a8-4f1e-9874-45d2c3723b80.png"), name="button_confirm_no_icon.png")

    ButtonContest = Image(path=sprite_path(r"46abcf20-513c-4759-9976-eaab68be7f8f.png"), name="button_contest.png")

    ButtonEnd = Image(path=sprite_path(r"b34a76e2-e318-47a0-b194-6e1b01eb269c.png"), name="button_end.png")

    ButtonHome = Image(path=sprite_path(r"cf89988c-c930-4890-8a55-018de7a4ae5a.png"), name="button_home.png")

    ButtonIconArrowShort = Image(path=sprite_path(r"e734df59-a24f-42e2-9f53-3ca720ddc612.png"), name="button_icon_arrow_short.png")

    ButtonIconArrowShortDisabled = Image(path=sprite_path(r"184e517f-f37f-4cc8-ac49-6858025903ee.png"), name="button_icon_arrow_short_disabled.png")

    ButtonIconCheckMark = Image(path=sprite_path(r"ceaa1281-57d5-4c32-b5e2-86781518709b.png"), name="button_icon_check_mark.png")

    ButtonIconClose = Image(path=sprite_path(r"8836e28c-e310-4870-94d2-b58e5dffad49.png"), name="button_icon_close.png")

    ButtonIdol = Image(path=sprite_path(r"fba7b4b2-46d3-4a5a-a161-6891014e6daf.png"), name="button_idol.png")

    ButtonIdolSupportCard = Image(path=sprite_path(r"9dcb4207-f546-4382-a87d-5d3377a31f4f.png"), name="button_idol_support_card.png")

    ButtonNext = Image(path=sprite_path(r"cca278bb-88cb-4898-8bbe-f52a49a0f740.png"), name="button_next.png")

    ButtonNextNoIcon = Image(path=sprite_path(r"5efaf4bf-b3cb-456f-88a1-ff1d28be80c1.png"), name="button_next_no_icon.png")

    ButtonRetry = Image(path=sprite_path(r"724e9b7b-0bf6-4d78-b887-9b108474e732.png"), name="button_retry.png")

    ButtonSelect = Image(path=sprite_path(r"81b9a59e-5714-459b-b6ce-03e1f4c4e503.png"), name="button_select.png")

    ButtonStart = Image(path=sprite_path(r"8f8f1144-5c30-41f0-8a6b-b39fe78e3e99.png"), name="button_start.png")

    ButtonToolbarHome = Image(path=sprite_path(r"87f96abd-8290-4a06-bfc4-c7275cd01d9a.png"), name="button_toolbar_home.png")

    ButtonToolbarMenu = Image(path=sprite_path(r"d55c4fd9-f8be-467a-923f-03cef8bd0525.png"), name="button_toolbar_menu.png")

    CheckboxUnchecked = Image(path=sprite_path(r"32966af9-8bfe-4b67-b9b5-2fd5e2678468.png"), name="checkbox_unchecked.png")

    TextGameUpdate = Image(path=sprite_path(r"f4212619-497f-4dcd-a197-e7c4c1c1a8ad.png"), name="text_game_update.png")

    TextNetworkError = Image(path=sprite_path(r"80bfcb8e-fb27-4240-85c5-61650419a304.png"), name="text_network_error.png")

    TextFastforwardCommuDialogTitle = Image(path=sprite_path(r"50e23c8a-7ba2-4c9c-9cfb-196c260fa1d5.png"), name="早送り確認")

    ButtonCommuSkip = Image(path=sprite_path(r"f1f21925-3e22-4dd1-b53b-bb52bcf26c2b.png"), name="跳过交流按钮")

    ButtonCommuFastforward = Image(path=sprite_path(r"f6ca6bd3-543f-4779-8367-c5c883f04b95.png"), name="快进交流按钮")

    ButtonOK = Image(path=sprite_path(r"8424ecdd-8857-4764-9fd0-d4bfa440c128.png"), name="OK 按钮")

    ButtonSelect2 = Image(path=sprite_path(r"5ebcde3b-f0fd-4e5d-b3de-ada8f0b5e03b.png"), name="選択する")

    TextSkipCommuComfirmation = Image(path=sprite_path(r"4d78add6-1027-4939-bb51-f99fca7db2ce.png"), name="跳过未读交流确认对话框标题")

    IconButtonCheck = Image(path=sprite_path(r"fad5eec2-5fd5-412f-9abb-987a3087dc54.png"), name="按钮✓图标")

    IconButtonCross = Image(path=sprite_path(r"bc7155ac-18c9-4335-9ec2-c8762d37a057.png"), name="按钮×图标")


    pass
class Daily:
    
    ButonLinkData = Image(path=sprite_path(r"5df708a6-1383-47a4-aec7-69f492f4f783.png"), name="buton_link_data.png")

    ButtonAssignmentPartial = Image(path=sprite_path(r"6e314b73-5ff5-4aa9-9dc3-1ebf28a578a7.png"), name="button_assignment_partial.png")

    ButtonClaimAllNoIcon = Image(path=sprite_path(r"5661e7a0-9513-4bb6-9549-87b7ad871a0d.png"), name="button_claim_all_no_icon.png")

    ButtonClubCollectReward = Image(path=sprite_path(r"ef601e20-dc47-4c70-a251-4238fde74d49.png"), name="button_club_collect_reward.png")

    ButtonClubSendGift = Image(path=sprite_path(r"53eca690-1c14-4424-9456-3a8397ae9ff3.png"), name="button_club_send_gift.png")

    ButtonClubSendGiftNext = Image(path=sprite_path(r"4999097e-2f8b-4965-9e7e-cb9801f8ed0e.png"), name="button_club_send_gift_next.png")

    ButtonContestChallenge = Image(path=sprite_path(r"7f459ed4-063c-48ab-a9ed-48f73bd3a865.png"), name="button_contest_challenge.png")

    ButtonContestChallengeStart = Image(path=sprite_path(r"0bab5a6b-631c-4661-8035-50a03299bd08.png"), name="button_contest_challenge_start.png")

    ButtonContestRanking = Image(path=sprite_path(r"b80cec57-1d9c-4e40-a4d2-df1e1b1546d3.png"), name="button_contest_ranking.png")

    ButtonContestStart = Image(path=sprite_path(r"9a9c9044-53c6-40f7-8eb5-2dc71383e58c.png"), name="button_contest_start.png")

    ButtonDailyShop = Image(path=sprite_path(r"395a07be-38b7-4c8c-948e-9efcb93a2e49.png"), name="button_daily_shop.png")

    ButtonHomeCurrent = Image(path=sprite_path(r"2f707d1b-98d5-47b1-a14c-5c7b95a1cc8c.png"), name="button_home_current.png")

    ButtonIconPass = Image(path=sprite_path(r"a8a3d531-9024-4603-a864-64bfe439a9ab.png"), name="button_icon_pass.png")

    ButtonIconSkip = Image(path=sprite_path(r"34fd0d97-1018-4986-b990-29e48abc2a56.png"), name="button_icon_skip.png")

    ButtonMission = Image(path=sprite_path(r"a7f4d9cb-d0ee-4abd-b9fa-148c059c7a0f.png"), name="button_mission.png")

    ButtonPass = Image(path=sprite_path(r"e072322f-eff1-4cbd-80c2-4e2103a1aa2f.png"), name="button_pass.png")

    ButtonPassClaim = Image(path=sprite_path(r"647e6110-8c89-4c34-9352-b8b321c61500.png"), name="button_pass_claim.png")

    ButtonPresentsPartial = Image(path=sprite_path(r"d88c35b8-f101-4557-b2a5-0f7846fecd4c.png"), name="button_presents_partial.png")

    ButtonProduce = Image(path=sprite_path(r"51d0f732-2fe9-40c5-b888-8143270d35bb.png"), name="button_produce.png")

    ButtonShop = Image(path=sprite_path(r"cdbf1f7f-63f6-40d7-a3b6-3d64bd6f9083.png"), name="button_shop.png")

    ButtonShopCapsuleToys = Image(path=sprite_path(r"f79fb63f-1737-4e67-b017-0b34bc93295a.png"), name="button_shop_capsule_toys.png")

    ButtonShopCapsuleToysDraw = Image(path=sprite_path(r"8d595a36-a900-42ea-871f-f17f99d5d73a.png"), name="button_shop_capsule_toys_draw.png")

    ButtonShopCountAdd = Image(path=sprite_path(r"e38ced13-5ab3-47ee-b10b-63b5ed4224fb.png"), name="button_shop_count_add.png")

    ButtonShopCountAddDisabled = Image(path=sprite_path(r"6dacc5c6-85e2-4e26-b7a4-6bda6cc3ed0e.png"), name="button_shop_count_add_disabled.png")

    ButtonSupportCardUpgrade = Image(path=sprite_path(r"f162875f-08d7-4a64-a7b2-2fff14497f74.png"), name="button_support_card_upgrade.png")

    ButtonRefreshMoneyShop = Image(path=sprite_path(r"81c97cd3-df53-44d3-bf3d-1eb4dc67b62a.png"), name="リスト更新：1回無料")

    IconTitleDailyShop = Image(path=sprite_path(r"e9ee330d-dfca-440e-8b8c-0a3b4e8c8730.png"), name="日常商店标题图标")

    BoxHomeAssignment = HintBox(x1=33, y1=650, x2=107, y2=746, source_resolution=(720, 1280))

    BoxHomeAP = HintBox(x1=291, y1=4, x2=500, y2=82, source_resolution=(720, 1280))

    BoxHomeJewel = HintBox(x1=500, y1=7, x2=703, y2=82, source_resolution=(720, 1280))

    BoxHomeActivelyFunds = HintBox(x1=29, y1=530, x2=109, y2=633, source_resolution=(720, 1280))

    IconAssignKouchou = Image(path=sprite_path(r"97f4f186-da9e-404c-bf1e-918f1b962fee.png"), name="icon_assign_kouchou.png")

    IconAssignMiniLive = Image(path=sprite_path(r"180168f7-9ead-4ce3-9cd9-b1960d649e5c.png"), name="icon_assign_mini_live.png")

    IconAssignOnlineLive = Image(path=sprite_path(r"d3832642-3108-4947-8274-68ad8a78b690.png"), name="icon_assign_online_live.png")

    IconAssignTitle = Image(path=sprite_path(r"44b34d58-8178-416f-88bc-a3c4a5a26bac.png"), name="icon_assign_title.png")

    IconMenuClub = Image(path=sprite_path(r"c1c710cd-885b-4b2c-9752-8a2754d0f72d.png"), name="icon_menu_club.png")

    IconShopAp = Image(path=sprite_path(r"034203b6-cadb-4b7c-af70-3e9551083457.png"), name="icon_shop_ap.png")

    IconShopMoney = Image(path=sprite_path(r"ccb670dd-7c8e-4bc9-8e73-934ce26d23a8.png"), name="icon_shop_money.png")

    IconShopTitle = Image(path=sprite_path(r"f8237a04-9f49-4796-9238-8dfab4cabcbe.png"), name="icon_shop_title.png")

    IconTitleAssign = Image(path=sprite_path(r"bbc8ae86-9ad5-4fc7-8662-05a096ec1b84.png"), name="icon_title_assign.png")

    IconTitlePass = Image(path=sprite_path(r"e707f860-027c-44ee-a7a3-b18573b539e3.png"), name="icon_title_pass.png")

    BoxApkUpdateDialogTitle = HintBox(x1=26, y1=905, x2=342, y2=967, source_resolution=(720, 1280))

    ButtonAssignmentShortenTime = Image(path=sprite_path(r"1652f06a-5417-49ef-8949-4854772d9ab7.png"), name="工作页面 短缩 时间")

    class Club:
        
        NoteRequestHintBox = HintBox(x1=314, y1=1071, x2=450, y2=1099, source_resolution=(720, 1280))
    
    
        pass
    TextRoadToIdol = Image(path=sprite_path(r"4503db6b-7224-4b81-9971-e7cfa56e10f2.png"), name="文字「アイドルへの道」")

    PointContest = HintPoint(x=492, y=878)

    PointDissmissContestReward = HintPoint(x=604, y=178)

    BoxMissonTabs = HintBox(x1=11, y1=929, x2=703, y2=1030, source_resolution=(720, 1280))

    class CapsuleToys:
        
        NextPageStartPoint = HintPoint(x=360, y=1167)
    
        NextPageEndPoint = HintPoint(x=362, y=267)
    
        IconTitle = Image(path=sprite_path(r"2bd6fe88-99fa-443d-8e42-bb3de5881213.png"), name="日常 扭蛋 页面标题图标")
    
        SliderStartPoint = HintPoint(x=476, y=898)
    
        SliderEndPoint = HintPoint(x=230, y=898)
    
    
        pass
    TextDefaultExchangeCountChangeDialog = Image(path=sprite_path(r"de325534-3fd3-480a-9eb8-eb47960a753a.png"), name="商店默认购买次数改变对话框")

    TextShopItemPurchased = Image(path=sprite_path(r"5d36b880-7b3f-49b1-a018-7de59867d376.png"), name="交換しました")

    TextShopItemSoldOut = Image(path=sprite_path(r"24dc7158-036c-4a66-9280-e934f470be53.png"), name="交換済みです")

    class SupportCard:
        
        DragDownStartPoint = HintPoint(x=357, y=872)
    
        DragDownEndPoint = HintPoint(x=362, y=194)
    
        TargetSupportCard = HintPoint(x=138, y=432)
    
    
        pass
    TextActivityFundsMax = Image(path=sprite_path(r"0411b7d9-8f30-44c8-ad51-fde15025ab5f.png"), name="text_activity_funds_max.png")

    TextAssignmentCompleted = Image(path=sprite_path(r"24b645e9-66a6-4c4b-8273-c895ba6b8324.png"), name="text_assignment_completed.png")

    TextContest = Image(path=sprite_path(r"c107e00b-f94f-4526-88f5-2eae03a7d7f6.png"), name="text_contest.png")

    TextContestLastOngoing = Image(path=sprite_path(r"1cc8c106-1830-433e-956f-7d31a01da99e.png"), name="text_contest_last_ongoing.png")

    TextContestNoMemory = Image(path=sprite_path(r"19962647-b587-488b-9ed3-1f4f7ce36406.png"), name="text_contest_no_memory.png")

    TextContestOverallStats = Image(path=sprite_path(r"444bc913-a075-4f71-baf8-a94cbb8a8ab0.png"), name="text_contest_overall_stats.png")

    TextShopRecommended = Image(path=sprite_path(r"c38d6852-316f-4a77-9987-e15789ee8612.png"), name="text_shop_recommended.png")

    TextTabShopAp = Image(path=sprite_path(r"c48df972-98fd-4303-99df-9374f542beda.png"), name="text_tab_shop_ap.png")


    pass
class Shop:
    
    ItemLessonNote = Image(path=sprite_path(r"0949c622-9067-4f0d-bac2-3f938a1d2ed2.png"), name="レッスンノート")

    ItemVeteranNote = Image(path=sprite_path(r"b2af59e9-60e3-4d97-8c72-c7ba092113a3.png"), name="ベテランノート")

    ItemSupportEnhancementPt = Image(path=sprite_path(r"835489e2-b29b-426c-b4c9-3bb9f8eb6195.png"), name="サポート強化Pt 支援强化Pt")

    ItemSenseNoteVocal = Image(path=sprite_path(r"c5b7d67e-7260-4f08-a0e9-4d31ce9bbecf.png"), name="センスノート（ボーカル）感性笔记（声乐）")

    ItemSenseNoteDance = Image(path=sprite_path(r"0f7d581d-cea3-4039-9205-732e4cd29293.png"), name="センスノート（ダンス）感性笔记（舞蹈）")

    ItemSenseNoteVisual = Image(path=sprite_path(r"d3cc3323-51af-4882-ae12-49e7384b746d.png"), name="センスノート（ビジュアル）感性笔记（形象）")

    ItemLogicNoteVocal = Image(path=sprite_path(r"a1df3af1-a3e7-4521-a085-e4dc3cd1cc57.png"), name="ロジックノート（ボーカル）理性笔记（声乐）")

    ItemLogicNoteDance = Image(path=sprite_path(r"a9fcaf04-0c1f-4b0f-bb5b-ede9da96180f.png"), name="ロジックノート（ダンス）理性笔记（舞蹈）")

    ItemLogicNoteVisual = Image(path=sprite_path(r"c3f536d6-a04a-4651-b3f9-dd2c22593f7f.png"), name="ロジックノート（ビジュアル）理性笔记（形象）")

    ItemAnomalyNoteVocal = Image(path=sprite_path(r"eef25cf9-afd0-43b1-b9c5-fbd997bd5fe0.png"), name="アノマリーノート（ボーカル）非凡笔记（声乐）")

    ItemAnomalyNoteDance = Image(path=sprite_path(r"df991b42-ed8e-4f2c-bf0c-aa7522f147b6.png"), name="アノマリーノート（ダンス）非凡笔记（舞蹈）")

    ItemAnomalyNoteVisual = Image(path=sprite_path(r"9340b854-025c-40da-9387-385d38433bef.png"), name="アノマリーノート（ビジュアル）非凡笔记（形象）")

    ItemRechallengeTicket = Image(path=sprite_path(r"ea1ba124-9cb3-4427-969a-bacd47e7d920.png"), name="再挑戦チケット 重新挑战券")

    ItemRecordKey = Image(path=sprite_path(r"1926f2f9-4bd7-48eb-9eba-28ec4efb0606.png"), name="記録の鍵  解锁交流的物品")

    class IdolPiece:
        
        花海咲季_FightingMyWay = Image(path=sprite_path(r"3942ae40-7f22-412c-aebe-4b064f68db9b.png"), name="")
    
        月村手毬_LunaSayMaybe = Image(path=sprite_path(r"185f7838-92a7-460b-9340-f60858948ce9.png"), name="")
    
        藤田ことね_世界一可愛い私  = Image(path=sprite_path(r"cb3d0ca7-8d14-408a-a2f5-2e25f7b86d6c.png"), name="")
    
        花海佑芽_TheRollingRiceball = Image(path=sprite_path(r"213016c2-c3a2-43d8-86a3-ab4d27666ced.png"), name="")
    
        葛城リーリヤ_白線 = Image(path=sprite_path(r"cc60b509-2ed5-493d-bb9f-333c6d2a6006.png"), name="")
    
        紫云清夏_TameLieOneStep = Image(path=sprite_path(r"5031808b-5525-4118-92b4-317ec8bda985.png"), name="")
    
        篠泽广_光景 = Image(path=sprite_path(r"ae9fe233-9acc-4e96-ba8e-1fb1d9bc2ea5.png"), name="")
    
        倉本千奈_WonderScale = Image(path=sprite_path(r"8f8b7b46-53bb-42ab-907a-4ea87eb09ab4.png"), name="")
    
        有村麻央_Fluorite = Image(path=sprite_path(r"0d9ac648-eefa-4869-ac99-1b0c83649681.png"), name="")
    
        姬崎莉波_clumsy_trick = Image(path=sprite_path(r"921eefeb-730e-46fc-9924-d338fb286592.png"), name="")
    
    
        pass

    pass
class Produce:
    
    BoxProduceOngoing = HintBox(x1=179, y1=937, x2=551, y2=1091, source_resolution=(720, 1280))

    ButtonAutoSet = Image(path=sprite_path(r"28282c09-6ce2-4d65-8475-1fc6fbf54e15.png"), name="button_auto_set.png")

    ButtonProduce = Image(path=sprite_path(r"4c4339dc-c9b2-4a3c-a80a-02512d281289.png"), name="button_produce.png")

    ButtonProduceStart = Image(path=sprite_path(r"8dfc96b9-678a-4126-914a-8b5ba920e280.png"), name="button_produce_start.png")

    ButtonRegular = Image(path=sprite_path(r"640826ef-c7cf-494c-888a-b151ef418531.png"), name="button_regular.png")

    CheckboxIconNoteBoost = Image(path=sprite_path(r"37686733-d013-4580-b255-6db73142c0f6.png"), name="checkbox_icon_note_boost.png")

    CheckboxIconSupportPtBoost = Image(path=sprite_path(r"0b3b7c7d-ad01-44dd-bd25-c819eb002a31.png"), name="checkbox_icon_support_pt_boost.png")

    IconPIdolLevel = Image(path=sprite_path(r"30a6f399-6999-4f04-bb77-651e0214112f.png"), name="P偶像卡上的等级图标")

    KbIdolOverviewName = HintBox(x1=140, y1=16, x2=615, y2=97, source_resolution=(720, 1280))

    BoxIdolOverviewIdols = HintBox(x1=26, y1=568, x2=696, y2=992, source_resolution=(720, 1280))

    ButtonResume = Image(path=sprite_path(r"ccbcb114-7f73-43d1-904a-3a7ae660c531.png"), name="再開する")

    ResumeDialogRegular = Image(path=sprite_path(r"daf3d823-b7f1-4584-acf3-90b9d880332c.png"), name="培育再开对话框 REGULAR")

    BoxResumeDialogWeeks = HintBox(x1=504, y1=559, x2=643, y2=595, source_resolution=(720, 1280))

    BoxResumeDialogIdolCard = HintBox(x1=53, y1=857, x2=197, y2=1048, source_resolution=(720, 1280))

    ResumeDialogPro = Image(path=sprite_path(r"c954e153-d3e9-4488-869f-d00cfdfac5ee.png"), name="培育再开对话框 PRO")

    ResumeDialogMaster = Image(path=sprite_path(r"3c8b477a-8eda-407e-9e9f-7540c8808f89.png"), name="培育再开对话框 MASTER")

    RadioTextSkipCommu = Image(path=sprite_path(r"2ebe4066-c47c-4284-a52d-b3f5bed523f3.png"), name="radio_text_skip_commu.png")

    TextAnotherIdolAvailableDialog = Image(path=sprite_path(r"cbf4ce9c-f8d8-4fb7-a197-15bb9847df04.png"), name="Another 版本偶像可用对话框标题")

    ScreenshotMemoryConfirmDialog = Image(path=sprite_path(r"d61a93e8-0e24-40d8-814a-402765d057ea.png"), name="screenshot_memory_confirm_dialog.png")

    LogoNia = Image(path=sprite_path(r"a0bd6a5f-784d-4f0a-9d66-10f4b80c8d3e.png"), name="NIA LOGO (NEXT IDOL AUDITION)")

    PointNiaToHajime = HintPoint(x=34, y=596)

    TextAPInsufficient = Image(path=sprite_path(r"4883c564-f950-4a29-9f5f-6f924123cd22.png"), name="培育 AP 不足提示弹窗 标题")

    ButtonRefillAP = Image(path=sprite_path(r"eaba6ebe-f0df-4918-aee5-ef4e3ffedcf0.png"), name="确认恢复AP按钮")

    ButtonUse = Image(path=sprite_path(r"cfc9c8e8-cbe1-49f0-9afa-ead7f9455a2e.png"), name="按钮「使う」")

    ScreenshotNoEnoughAp3 = Image(path=sprite_path(r"649f1c6d-03f8-4e84-87a7-b3418bdb9f61.png"), name="screenshot_no_enough_ap_3.png")

    ButtonSkipLive = Image(path=sprite_path(r"e5e84f9e-28da-4cf4-bcba-c9145fe39b07.png"), name="培育结束跳过演出按钮")

    TextSkipLiveDialogTitle = Image(path=sprite_path(r"b6b94f21-ef4b-4425-9c7e-ca2b574b0add.png"), name="跳过演出确认对话框标题")

    ButtonHajime0Regular = Image(path=sprite_path(r"6cd80be8-c9b3-4ba5-bf17-3ffc9b000743.png"), name="")

    ButtonHajime0Pro = Image(path=sprite_path(r"55f7db71-0a18-4b3d-b847-57959b8d2e32.png"), name="")

    TitleIconProudce = Image(path=sprite_path(r"0bf5e34e-afc6-4447-bbac-67026ce2ad26.png"), name="培育页面左上角标题图标")

    ButtonHajime1Regular = Image(path=sprite_path(r"3b473fe6-e147-477f-b088-9b8fb042a4f6.png"), name="")

    ButtonHajime1Pro = Image(path=sprite_path(r"2ededcf5-1d80-4e2a-9c83-2a31998331ce.png"), name="")

    ButtonHajime1Master = Image(path=sprite_path(r"24e99232-9434-457f-a9a0-69dd7ecf675f.png"), name="")

    PointHajimeToNia = HintPoint(x=680, y=592)

    LogoHajime = Image(path=sprite_path(r"e6b45405-cd9f-4c6e-a9f1-6ec953747c65.png"), name="Hajime LOGO 定期公演")

    ButtonPIdolOverview = Image(path=sprite_path(r"e88c9ad1-ec37-4fcd-b086-862e1e7ce8fd.png"), name="Pアイドルー覧  P偶像列表展示")

    TextStepIndicator1 = Image(path=sprite_path(r"44ba8515-4a60-42c9-8878-b42e4e34ee15.png"), name="1. アイドル選択")

    BoxSelectedIdol = HintBox(x1=149, y1=783, x2=317, y2=1006, source_resolution=(720, 1280))

    BoxSetCountIndicator = HintBox(x1=66, y1=651, x2=139, y2=686, source_resolution=(720, 1280))

    PointProduceNextSet = HintPoint(x=702, y=832)

    PointProducePrevSet = HintPoint(x=14, y=832)

    TextStepIndicator2 = Image(path=sprite_path(r"a48324ae-7c1a-489e-b3c4-93d12267f88d.png"), name="2. サポート選択")

    EmptySupportCardSlot = Image(path=sprite_path(r"d3424d31-0502-4623-996e-f0194e5085ce.png"), name="空支援卡槽位")

    TextAutoSet = Image(path=sprite_path(r"f5c16d2f-ebc5-4617-9b96-971696af7c52.png"), name="おまかせ編成")

    TextStepIndicator3 = Image(path=sprite_path(r"f43c313b-8a7b-467b-8442-fc5bcb8b4388.png"), name="3.メモリー選択")

    TextRentAvailable = Image(path=sprite_path(r"74ec3510-583d-4a76-ac69-38480fbf1387.png"), name="レンタル可能")

    TextStepIndicator4 = Image(path=sprite_path(r"b62bf889-da3c-495a-8707-f3bde73efe92.png"), name="4.開始確認")


    pass
class InPurodyuusu:
    
    A = Image(path=sprite_path(r"88456f07-23f0-48f7-ac81-206312717095.png"), name="A.png")

    AcquireBtnDisabled = Image(path=sprite_path(r"a5e675c9-8fc8-46f2-ae73-bc871d65daaf.png"), name="acquire_btn_disabled.png")

    ButtonCancel = Image(path=sprite_path(r"974015ca-854d-43e3-a8ed-faa247d304bc.png"), name="button_cancel.png")

    ButtonComplete = Image(path=sprite_path(r"32395105-71b0-4f98-a439-c181e82a648e.png"), name="button_complete.png")

    ButtonFinalPracticeDance = Image(path=sprite_path(r"faeb1498-1c11-4bc7-8e85-864fd876751c.png"), name="button_final_practice_dance.png")

    ButtonFinalPracticeVisual = Image(path=sprite_path(r"1989466d-c486-4e0c-acc9-ed3116e3c0b8.png"), name="button_final_practice_visual.png")

    ButtonFinalPracticeVocal = Image(path=sprite_path(r"5af6d58e-52c5-47fd-8ea5-c2fa8bb67e99.png"), name="button_final_practice_vocal.png")

    ButtonFollowNoIcon = Image(path=sprite_path(r"7465297a-497d-41fa-948d-7f04ad5fdc94.png"), name="button_follow_no_icon.png")

    ButtonIconStudy = Image(path=sprite_path(r"a43abe98-376b-4da7-ab17-b6c9e1a875fb.png"), name="button_icon_study.png")

    ButtonIconStudyVisual = Image(path=sprite_path(r"38526b38-7f62-466b-8702-0c657891c7fa.png"), name="button_icon_study_visual.png")

    ButtonLeave = Image(path=sprite_path(r"4fa138a2-4f39-4023-afd4-af5be7df662b.png"), name="button_leave.png")

    ButtonNextNoIcon = Image(path=sprite_path(r"d61df6da-4b09-4b8c-bc97-46632a80fcd9.png"), name="button_next_no_icon.png")

    ButtonRetry = Image(path=sprite_path(r"725e767e-79bb-4ce6-a448-8ebee80193b7.png"), name="button_retry.png")

    ButtonTextActionOuting = Image(path=sprite_path(r"f68eb4f1-b30b-43fc-8a24-11394cc759d2.png"), name="button_text_action_outing.png")

    ButtonTextAllowance = Image(path=sprite_path(r"64969b0b-a6ef-4342-a967-20428d5baa65.png"), name="button_text_allowance.png")

    ButtonTextConsult = Image(path=sprite_path(r"cdd7bbc5-8ebd-4a5c-84ca-0e7ca7702d8f.png"), name="button_text_consult.png")

    IconClearBlue = Image(path=sprite_path(r"8fad2402-594e-4466-927a-1f83139d7edf.png"), name="icon_clear_blue.png")

    IconTitleAllowance = Image(path=sprite_path(r"2e76fba4-b9db-47ce-b6a4-d0a857b3fd4b.png"), name="icon_title_allowance.png")

    IconTitleStudy = Image(path=sprite_path(r"cc65d34b-b220-451e-a18e-66b05b911e97.png"), name="icon_title_study.png")

    LootboxSliverLock = Image(path=sprite_path(r"c35208a6-261e-4a2e-aeae-aae19d8c83d6.png"), name="lootbox_sliver_lock.png")

    LootBoxSkillCard = Image(path=sprite_path(r"9d87795b-c322-49c6-a9c9-6064828a55a2.png"), name="loot_box_skill_card.png")

    M = Image(path=sprite_path(r"e129c096-35c3-4fd8-b30c-ce92c3c9b85f.png"), name="M.png")

    BoxExamTop = HintBox(x1=5, y1=2, x2=712, y2=55, source_resolution=(720, 1280))

    BoxCardLetter = HintBox(x1=6, y1=1081, x2=715, y2=1100, source_resolution=(720, 1280))

    PDrinkIcon = Image(path=sprite_path(r"441934e4-3659-4522-985c-0e683eb03f1c.png"), name="p_drink_icon.png")

    PItemIconColorful = Image(path=sprite_path(r"97f26adc-071b-4289-8243-dc20e024c7e4.png"), name="p_item_icon_colorful.png")

    PSkillCardIconBlue = Image(path=sprite_path(r"5e473a8c-bf57-44d8-a711-db1f4ccc182c.png"), name="p_skill_card_icon_blue.png")

    PSkillCardIconColorful = Image(path=sprite_path(r"d67de935-b5f2-4176-ab52-d0482290cb59.png"), name="p_skill_card_icon_colorful.png")

    Rest = Image(path=sprite_path(r"6fe17986-a29d-4198-b366-1c40637069b5.png"), name="rest.png")

    RestConfirmBtn = Image(path=sprite_path(r"87b36188-2bf9-4b56-98cf-9e8df3879dbf.png"), name="rest_confirm_btn.png")

    Screenshot4Cards = Image(path=sprite_path(r"62b425ac-3e19-4924-8a58-c085f4d38f56.png"), name="screenshot_4_cards.png")

    Screenshot5Cards = Image(path=sprite_path(r"50718df3-1b0e-425f-802c-ca4abd08a4b5.png"), name="screenshot_5_cards.png")

    BoxWeeksUntilExam = HintBox(x1=11, y1=8, x2=237, y2=196, source_resolution=(720, 1280))

    TextActionVocal = Image(path=sprite_path(r"d6b64759-26b7-45b1-bf8e-5c0d98611e0d.png"), name="Vo. レッスン")

    TextActionDance = Image(path=sprite_path(r"303cccc1-c674-4d3a-8c89-19ea729fdbef.png"), name="Da. レッスン")

    TextActionVisual = Image(path=sprite_path(r"cc8a495d-330d-447d-8a80-a8a6ecc409c5.png"), name="Vi. レッスン")

    IconAsariSenseiAvatar = Image(path=sprite_path(r"d7667903-7149-4f2f-9c15-d8a4b5f4d347.png"), name="Asari 老师头像")

    BoxAsariSenseiTip = HintBox(x1=245, y1=150, x2=702, y2=243, source_resolution=(720, 1280))

    ButtonPracticeVocal = Image(path=sprite_path(r"ce1d1d6f-38f2-48bf-98bd-6e091c7ca5b8.png"), name="行动页 声乐课程按钮图标")

    ButtonPracticeDance = Image(path=sprite_path(r"b2e1bf3c-2c36-4fb5-9db7-c10a29563a37.png"), name="行动页 舞蹈课程按钮图标")

    ButtonPracticeVisual = Image(path=sprite_path(r"adc533a7-970b-4c5b-a037-2181531a35d6.png"), name="行动页 形象课程按钮图标")

    TextFinalExamRemaining = Image(path=sprite_path(r"70898bf8-56c5-4f84-becb-629c9ab6a7da.png"), name="最終まで")

    ButtonIconOuting = Image(path=sprite_path(r"8ded6c98-85ea-4858-a66d-4fc8caecb7c5.png"), name="行动按钮图标 外出（おでかけ）")

    ButtonIconConsult = Image(path=sprite_path(r"d83f338d-dde3-494b-9bea-cae511e3517c.png"), name="行动按钮图标 咨询（相談）")

    TextMidExamRemaining = Image(path=sprite_path(r"ce20a856-5629-4f8e-a8e1-d1bd14e18e4f.png"), name="中間まで")

    IconTitleConsult = Image(path=sprite_path(r"23d88465-65d9-4718-8725-8dbf0a98a5a4.png"), name="「相談」页面左上角图标")

    PointConsultFirstItem = HintPoint(x=123, y=550)

    ButtonEndConsult = Image(path=sprite_path(r"9fd0753f-c607-4d49-82d1-40bda27e014f.png"), name="相談 结束按钮")

    ButtonIconExchange = Image(path=sprite_path(r"4096cffa-a889-4622-852e-760fc7022d93.png"), name="交换按钮的图标")

    TextExchangeConfirm = Image(path=sprite_path(r"25f00ee3-8dfe-42d1-a67e-191fa5c3df4b.png"), name="交換確認")

    TextGoalClearNext = Image(path=sprite_path(r"05890a1b-8764-4e9f-9d21-65d292c22e13.png"), name="培育目标达成 NEXT 文字")

    BoxLessonCards5_1 = HintBox(x1=16, y1=882, x2=208, y2=1136, source_resolution=(720, 1280))

    BoxNoSkillCard = HintBox(x1=180, y1=977, x2=529, y2=1026, source_resolution=(720, 1280))

    TitleIconOuting = Image(path=sprite_path(r"ee4e512b-4982-49b6-9c71-31984b58e1d0.png"), name="外出（おでかけ）页面 标题图标")

    TextPDrinkMaxConfirmTitle = Image(path=sprite_path(r"582d36c0-0916-4706-9833-4fbc026701f5.png"), name="P饮料溢出 不领取弹窗标题")

    IconTitleSkillCardRemoval = Image(path=sprite_path(r"bab6c393-692c-4681-ac0d-76c0d9dabea6.png"), name="技能卡自选删除 标题图标")

    ButtonRemove = Image(path=sprite_path(r"00551158-fee9-483f-b034-549139a96f58.png"), name="削除")

    TextPDrink = Image(path=sprite_path(r"8c179a21-be6f-4db8-a9b0-9afeb5c36b1c.png"), name="文本「Pドリンク」")

    TextDontClaim = Image(path=sprite_path(r"e4683def-8d1d-472b-a5ab-bb3885c0c98e.png"), name="受け取らない")

    ButtonDontClaim = Image(path=sprite_path(r"447d0e44-5d87-4b7c-8e60-edb111fe1639.png"), name="「受け取らない」按钮")

    BoxSelectPStuffComfirm = HintBox(x1=256, y1=1064, x2=478, y2=1128, source_resolution=(720, 1280))

    TextClaim = Image(path=sprite_path(r"c948f136-416f-447e-8152-54a1cd1d1329.png"), name="文字「受け取る」")

    TextPItem = Image(path=sprite_path(r"0c0627be-4a09-4450-a078-1858d3ace532.png"), name="文字「Pアイテム」")

    TextSkillCard = Image(path=sprite_path(r"d271a24f-efe8-424d-8fd5-f6b3756ba4ca.png"), name="文字「スキルカード」")

    TextRecommend = Image(path=sprite_path(r"b0283997-7931-476d-a92f-d7569f6ea34c.png"), name="おすすめ")

    ScreenshotSenseiTipConsult = Image(path=sprite_path(r"814da106-1756-4bce-9140-d2730b635e7e.png"), name="screenshot_sensei_tip_consult.png")

    TextSkillCardSelectGuideDialogTitle = Image(path=sprite_path(r"3f637e86-6b74-4693-9131-1fe411fc21e5.png"), name="獲得ガイド表示設定")

    BoxSkillCardAcquired = HintBox(x1=194, y1=712, x2=528, y2=765, source_resolution=(720, 1280))

    IconSkillCardEventBubble = Image(path=sprite_path(r"6b58d90d-2e5e-4b7f-bc01-941f2633de89.png"), name="技能卡事件气泡框图标")

    ScreenshotSkillCardEnhanceDialog = Image(path=sprite_path(r"6e3515d4-68ce-4760-948b-5fb20576fc12.png"), name="screenshot_skill_card_enhance_dialog.png")

    IconTitleSkillCardEnhance = Image(path=sprite_path(r"79abd239-5eed-4195-9fa8-d729daa874ca.png"), name="技能卡强化 标题 图标")

    ButtonEnhance = Image(path=sprite_path(r"da439e8c-3b74-4371-9657-0736d826c7d1.png"), name="技能卡 强化按钮")

    IconTitleSkillCardMove = Image(path=sprite_path(r"db7d3f03-1f7f-43bf-8125-f7c2d345fca2.png"), name="培育中技能卡移动对话框")

    BoxSkillCardMoveButtonCount = HintBox(x1=339, y1=1170, x2=381, y2=1195, source_resolution=(720, 1280))

    T = Image(path=sprite_path(r"16fbc93d-b294-4001-b4e9-ee2af181415f.png"), name="睡意卡字母 T（眠気）")

    IconSp = Image(path=sprite_path(r"d982d2b5-4bc0-4ae9-a516-f29c2848d64b.png"), name="SP 课程图标")

    BoxCommuEventButtonsArea = HintBox(x1=14, y1=412, x2=703, y2=1089, source_resolution=(720, 1280))

    TextSelfStudyVocal = Image(path=sprite_path(r"c78c38cc-7b61-4dc4-820d-0a5b684ef52e.png"), name="文化课事件 自习 声乐")

    TextSelfStudyDance = Image(path=sprite_path(r"83d0a033-466c-463a-bb8c-be0f2953e9b2.png"), name="文化课事件 自习 舞蹈")

    TextSelfStudyVisual = Image(path=sprite_path(r"4695f96b-c4f5-4bb6-a021-a13b6ceb2883.png"), name="文化课事件 自习 形象")

    TextAsariProduceEnd = Image(path=sprite_path(r"71841087-2d73-4726-943a-c784df0b0d2d.png"), name="text_asari_produce_end.png")

    TextButtonExamSkipTurn = Image(path=sprite_path(r"6a77517b-99b1-42a1-ba61-a3109151339e.png"), name="text_button_exam_skip_turn.png")

    TextClearUntil = Image(path=sprite_path(r"8af8652d-06fe-4d2c-b123-641c7fbc651d.png"), name="text_clear_until.png")

    TextDance = Image(path=sprite_path(r"3d8ab1bb-f8a8-4b19-a565-3b06e1cfe11c.png"), name="text_dance.png")

    TextFinalProduceRating = Image(path=sprite_path(r"c32068c9-6e52-4176-98de-fd4d252969dd.png"), name="text_final_produce_rating.png")

    TextOneWeekRemaining = Image(path=sprite_path(r"998be65c-b835-4004-bbe0-411a4d74985c.png"), name="text_one_week_remaining.png")

    TextPerfectUntil = Image(path=sprite_path(r"59f54f2a-1efb-4d5a-b76b-b740ddf561ec.png"), name="text_perfect_until.png")

    TextPleaseSelectPDrink = Image(path=sprite_path(r"2af71658-11c3-4c34-b604-003fb8a6a542.png"), name="text_please_select_p_drink.png")

    TextPDiary = Image(path=sprite_path(r"a938bf45-e622-424f-829a-76152586f413.png"), name="text_p_diary.png")

    TextPDrinkMax = Image(path=sprite_path(r"be8a47df-79fe-48c1-b41e-77fe1a26a90b.png"), name="text_p_drink_max.png")

    TextSenseiTipConsult = Image(path=sprite_path(r"56c4d716-65b3-4fb8-badb-970853544c7a.png"), name="text_sensei_tip_consult.png")

    TextSenseiTipDance = Image(path=sprite_path(r"e2287baf-c165-467b-8b6c-640d1f2ee376.png"), name="text_sensei_tip_dance.png")

    TextSenseiTipRest = Image(path=sprite_path(r"288ca9e3-237f-4de6-ba06-e586a9f87d03.png"), name="text_sensei_tip_rest.png")

    TextSenseiTipVisual = Image(path=sprite_path(r"87ee5cea-6fb4-4768-8767-3c422df08371.png"), name="text_sensei_tip_visual.png")

    TextSenseiTipVocal = Image(path=sprite_path(r"d289f4e1-e92e-4263-93a4-33da4767d7a9.png"), name="text_sensei_tip_vocal.png")

    TextSkipTurnDialog = Image(path=sprite_path(r"9ac47ce9-2594-4740-ba70-c61f97c0f992.png"), name="text_skip_turn_dialog.png")

    TextVisual = Image(path=sprite_path(r"b6f57baa-1d05-464f-81c9-0014063d6656.png"), name="text_visual.png")


    pass
class Kuyo:
    
    ButtonStartGame = Image(path=sprite_path(r"15552124-cc5c-4abe-b08d-123624248d77.png"), name="button_start_game.png")

    ButtonTab3Speedup = Image(path=sprite_path(r"cac8bff8-569e-450f-8ac7-dad3eebf18d9.png"), name="button_tab3_speedup.png")


    pass